==> jc-1.4.0.tar.gz: gnu/java/awt/color/ToneReproductionCurve.h <==
// public class gnu.java.awt.color.ToneReproductionCurve

// class file dependencies
// @dep_class a1933b2f9939f4ab gnu_java_awt_color_ToneReproductionCurve
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ToneReproductionCurve_H_
#define _JC_gnu_java_awt_color_ToneReproductionCurve_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs	_jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs	_jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$refs	_jc_gnu_java_awt_color_ToneReproductionCurve$refs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs	_jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	_jc_gnu_java_awt_color_ToneReproductionCurve$object;

typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vmethods	_jc_gnu_java_awt_color_ToneReproductionCurve$vmethods;
typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtable	_jc_gnu_java_awt_color_ToneReproductionCurve$vtable;
typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtype	_jc_gnu_java_awt_color_ToneReproductionCurve$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat);
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$24d83f20a0ca62ab(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, struct _jc_float_array *);
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$e9e7916920e19e25(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, struct _jc_short_array *);

// Virtual methods
extern jfloat _jc_gnu_java_awt_color_ToneReproductionCurve$method$lookup$8ad35d6d0b313e69(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat);
extern jfloat _jc_gnu_java_awt_color_ToneReproductionCurve$method$reverseLookup$6789894c9072780b(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat);
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$setupReverseTrc$424a0707920d017d(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$lookup$8ad35d6d0b313e69;
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$reverseLookup$6789894c9072780b;
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$setupReverseTrc$424a0707920d017d;

// Virtual methods structure
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vmethods {
	jfloat	(*lookup$8ad35d6d0b313e69)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat);
	jfloat	(*reverseLookup$6789894c9072780b)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat);
	void	(*setupReverseTrc$424a0707920d017d)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *);
};

// Vtable
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vmethods	gnu_java_awt_color_ToneReproductionCurve;
};

// Vtype
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs {
	_jc_float_array	*trc;
	_jc_float_array	*reverseTrc;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$refs {
    _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs	gnu_java_awt_color_ToneReproductionCurve;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs {
	jfloat	gamma;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs	gnu_java_awt_color_ToneReproductionCurve;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object {
	_jc_gnu_java_awt_color_ToneReproductionCurve$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vtype	*vtype;
	_jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ToneReproductionCurve$vtype _jc_gnu_java_awt_color_ToneReproductionCurve$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ToneReproductionCurve, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ToneReproductionCurve$class_object;

#endif	/* _JC_gnu_java_awt_color_ToneReproductionCurve_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/ToneReproductionCurve.h <==
// public class gnu.java.awt.color.ToneReproductionCurve

// class file dependencies
// @dep_class 19ce4b0407f6ce50 gnu_java_awt_color_ToneReproductionCurve
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ToneReproductionCurve_H_
#define _JC_gnu_java_awt_color_ToneReproductionCurve_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs	_jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs	_jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$refs	_jc_gnu_java_awt_color_ToneReproductionCurve$refs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs	_jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs;
typedef struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	_jc_gnu_java_awt_color_ToneReproductionCurve$object;

typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vmethods	_jc_gnu_java_awt_color_ToneReproductionCurve$vmethods;
typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtable	_jc_gnu_java_awt_color_ToneReproductionCurve$vtable;
typedef const struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtype	_jc_gnu_java_awt_color_ToneReproductionCurve$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$24d83f20a0ca62ab(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$_init$e9e7916920e19e25(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, struct _jc_short_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jfloat _jc_gnu_java_awt_color_ToneReproductionCurve$method$lookup$8ad35d6d0b313e69(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat) _JC_JCNI_ATTR;
extern jfloat _jc_gnu_java_awt_color_ToneReproductionCurve$method$reverseLookup$6789894c9072780b(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_ToneReproductionCurve$method$setupReverseTrc$424a0707920d017d(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$lookup$8ad35d6d0b313e69;
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$reverseLookup$6789894c9072780b;
extern _jc_method _jc_gnu_java_awt_color_ToneReproductionCurve$method_info$setupReverseTrc$424a0707920d017d;

// Virtual methods structure
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vmethods {
	jfloat	(*lookup$8ad35d6d0b313e69)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat) _JC_JCNI_ATTR;
	jfloat	(*reverseLookup$6789894c9072780b)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *, jfloat) _JC_JCNI_ATTR;
	void	(*setupReverseTrc$424a0707920d017d)(_jc_env *, struct _jc_gnu_java_awt_color_ToneReproductionCurve$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vmethods	gnu_java_awt_color_ToneReproductionCurve;
};

// Vtype
struct _jc_gnu_java_awt_color_ToneReproductionCurve$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs {
	_jc_float_array	*trc;
	_jc_float_array	*reverseTrc;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$refs {
    _jc_gnu_java_awt_color_ToneReproductionCurve$sub_refs	gnu_java_awt_color_ToneReproductionCurve;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs {
	jfloat	gamma;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ToneReproductionCurve$sub_nonrefs	gnu_java_awt_color_ToneReproductionCurve;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object {
	_jc_gnu_java_awt_color_ToneReproductionCurve$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ToneReproductionCurve$vtype	*vtype;
	_jc_gnu_java_awt_color_ToneReproductionCurve$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ToneReproductionCurve$vtype _jc_gnu_java_awt_color_ToneReproductionCurve$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ToneReproductionCurve, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ToneReproductionCurve$class_object;

#endif	/* _JC_gnu_java_awt_color_ToneReproductionCurve_H_ */
